==> kde4pim_3.92.0.orig.tar.gz: kdepim-3.92.0/kaddressbook/kaddressbookservice.cpp <==
/*
    This file is part of KAddressbook.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#include "core.h"

#include "kaddressbookservice.h"
#include "serviceadaptor.h"
#include <QtDBus>

KAddressBookService::KAddressBookService( KAB::Core *core )
  : mCore( core )
{
  new ServiceAdaptor( this );
  QDBusConnection::sessionBus().registerObject( "/AddressBookService", this, QDBusConnection::ExportAdaptors );
}

void KAddressBookService::importVCard( const QString& vCard )
{
  mCore->importVCard( vCard );
}

void KAddressBookService::importVCard( const KUrl& url )
{
  mCore->importVCard( url );
}

==> kde4pim_3.94.0.orig.tar.gz: kdepim-3.94.0/kaddressbook/kaddressbookservice.cpp <==
/*
    This file is part of KAddressbook.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#include "core.h"

#include "kaddressbookservice.h"
#include "serviceadaptor.h"
#include <QtDBus>

KAddressBookService::KAddressBookService( KAB::Core *core )
  : mCore( core )
{
  new ServiceAdaptor( this );
  QDBusConnection::sessionBus().registerObject( "/AddressBookService", this, QDBusConnection::ExportAdaptors );
}

void KAddressBookService::importVCardFromData( const QString& vCard )
{
  mCore->importVCardFromData( vCard );
}

void KAddressBookService::importVCard( const KUrl& url )
{
  mCore->importVCard( url );
}
